pub struct Cloud<const N: usize, F: Field> { /* private fields */ }Expand description
Defines the Cloud struct, representing a collection of points (vectors)
in an N-dimensional space.
This module provides the Cloud type, which can be used to store and
manage a set of points. It implements traits for basic collection operations,
as well as for metric and normed space concepts, allowing for calculations
like distance and norm.
A Cloud is essentially a set of vectors, providing basic Collection operations
as well as metric and normed space functionalities.
Implementations
Sourceimpl<F: Field, const N: usize> Cloud<N, F>
impl<F: Field, const N: usize> Cloud<N, F>
Sourcepub const fn new(points: Vec<FixedVector<N, F>>) -> Self
pub const fn new(points: Vec<FixedVector<N, F>>) -> Self
Creates a new Cloud from a given set of points.
Arguments
points: AHashSetofVector<N, F>representing the points in the cloud.
Sourcepub const fn points_ref(&self) -> &Vec<FixedVector<N, F>>
pub const fn points_ref(&self) -> &Vec<FixedVector<N, F>>
Returns a reference to the points in the cloud.