DirectedType

Trait DirectedType 

pub trait DirectedType: Sealed { }
A trait to distinguish between directed and undirected graphs.

This trait is sealed and can only be implemented by the Directed and Undirected types provided in this module.

Implementors