pub struct Graph<V, D: DirectedType> { /* private fields */ }Expand description
A graph data structure supporting both directed and undirected graphs.
Type Parameters
V- The type of vertex identifiersD- The directedness type (DirectedorUndirected)
Examples
use std::collections::HashSet;
let mut vertices = HashSet::new();
vertices.insert(1);
vertices.insert(2);
let mut edges = HashSet::new();
edges.insert((1, 2));
let graph = Graph::<usize, Undirected>::new(vertices, edges);Implementations
Sourceimpl<V: PartialOrd + Eq + Hash> Graph<V, Undirected>
impl<V: PartialOrd + Eq + Hash> Graph<V, Undirected>
Sourcepub fn new(vertices: HashSet<V>, edges: HashSet<(V, V)>) -> Self
pub fn new(vertices: HashSet<V>, edges: HashSet<(V, V)>) -> Self
Creates a new graph with the given vertices and edges.
For undirected graphs, edges are normalized so that the smaller vertex
(by PartialOrd) is always first in the pair.
Arguments
vertices- The set of vertices in the graphedges- The set of edges in the graph
Panics
- If any edge references a vertex not in the vertex set
Sourceimpl<V: PartialOrd + Eq + Hash> Graph<V, Directed>
impl<V: PartialOrd + Eq + Hash> Graph<V, Directed>
Sourcepub fn new(vertices: HashSet<V>, edges: HashSet<(V, V)>) -> Self
pub fn new(vertices: HashSet<V>, edges: HashSet<(V, V)>) -> Self
Creates a new graph with the given vertices and edges.
For undirected graphs, edges are normalized so that the smaller vertex
(by PartialOrd) is always first in the pair.
Arguments
vertices- The set of vertices in the graphedges- The set of edges in the graph
Panics
- If any edge references a vertex not in the vertex set